videocollection/videocollectionwrapper/inc/videocollectionutils.h
changeset 17 69946d1824c4
parent 15 cf5481c2bc0b
child 20 b9e04db066d4
--- a/videocollection/videocollectionwrapper/inc/videocollectionutils.h	Fri Apr 16 14:59:52 2010 +0300
+++ b/videocollection/videocollectionwrapper/inc/videocollectionutils.h	Mon May 03 12:32:50 2010 +0300
@@ -125,12 +125,12 @@
     QString prepareLengthString(quint32 length);
     
     /**
      * Prepares length strings from given value.
      * 
      * @param length Length value in seconds.
-     * @return Lengths as QStringList, first item tells the minutes, second tells seconds
+     * @return Length as QString (for example "00:25:10").
      */
-    const QStringList prepareLengthStrings(quint32 total);
+    const QString prepareShortLengthString(quint32 total);
     
     /**
      * Prepares size string from the given value.
@@ -125,12 +125,12 @@
     
     /**
-     * Prepares length strings from given value.
+     * Prepares length string from given value in short format.
      * 
      * @param length Length value in seconds.